pitchtools.HarmonicCounterpointInterval
=======================================

.. autoclass:: abjad.tools.pitchtools.HarmonicCounterpointInterval
   :members:
   :undoc-members:
   :show-inheritance:
